
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.29.3.post1',
    'branch_nick': 'release-1.29-LTS',
    'revision_id': 'fe2b8e1d601995de14ca02442f0df7c644a8fd7e',
    'revno': 11978
}
